@@ -5,12 +5,13 @@ from dateutil.relativedelta import relativedelta
 
 import pycountry
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import POOL, USER, CONTEXT
+from trytond.tests.test_tryton import POOL, USER
 from nereid.testing import NereidTestCase
 from trytond.transaction import Transaction
 from trytond.config import config
 
 config.set('database', 'path', '/tmp')
+config.set('email', 'from', 'from@xyz.com')
 
 
 class BaseTestCase(NereidTestCase):
@@ -98,7 +99,8 @@ class BaseTestCase(NereidTestCase):
         return self.Category.create(vlist)
 
     def _create_product_template(
-        self, name, vlist, uri, uom=u'Unit', displayed_on_eshop=True
+        self, name, vlist, uri, uom=u'Unit', displayed_on_eshop=True,
+        list_price=Decimal('10'), cost_price=Decimal('5')
     ):
         """
         Create a product template with products and return its ID
@@ -118,6 +120,8 @@ class BaseTestCase(NereidTestCase):
             _code_list.append(code)
 
         for values in vlist:
+            category = values.pop('category')
+            values['categories'] = [('add', [category])]
             values['name'] = name
             values['default_uom'], = self.Uom.search(
                 [('name', '=', uom)], limit=1
@@ -125,6 +129,8 @@ class BaseTestCase(NereidTestCase):
             values['sale_uom'], = self.Uom.search(
                 [('name', '=', uom)], limit=1
             )
+            values['list_price'] = list_price
+            values['cost_price'] = cost_price
             values['products'] = [
                 ('create', [{
                     'uri': uri,
@@ -142,12 +148,12 @@ class BaseTestCase(NereidTestCase):
                 'category': self.category.id,
                 'type': 'goods',
                 'salable': True,
-                'list_price': Decimal('10'),
-                'cost_price': Decimal('5'),
                 'account_expense': self._get_account_by_kind('expense').id,
                 'account_revenue': self._get_account_by_kind('revenue').id,
             }],
             uri='product-1',
+            list_price=Decimal('10'),
+            cost_price=Decimal('5'),
         )
         self._create_product_template(
             'product 2',
@@ -155,36 +161,36 @@ class BaseTestCase(NereidTestCase):
                 'category': self.category2.id,
                 'type': 'goods',
                 'salable': True,
-                'list_price': Decimal('20'),
-                'cost_price': Decimal('5'),
                 'account_expense': self._get_account_by_kind('expense').id,
                 'account_revenue': self._get_account_by_kind('revenue').id,
             }],
             uri='product-2',
+            list_price=Decimal('10'),
+            cost_price=Decimal('5'),
         )
         self._create_product_template(
             'product 3',
             [{
                 'category': self.category3.id,
                 'type': 'goods',
-                'list_price': Decimal('30'),
-                'cost_price': Decimal('5'),
                 'account_expense': self._get_account_by_kind('expense').id,
                 'account_revenue': self._get_account_by_kind('revenue').id,
             }],
             uri='product-3',
+            list_price=Decimal('10'),
+            cost_price=Decimal('5'),
         )
         self._create_product_template(
             'product 4',
             [{
                 'category': self.category3.id,
                 'type': 'goods',
-                'list_price': Decimal('30'),
-                'cost_price': Decimal('5'),
                 'account_expense': self._get_account_by_kind('expense').id,
                 'account_revenue': self._get_account_by_kind('revenue').id,
             }],
             uri='product-4',
+            list_price=Decimal('10'),
+            cost_price=Decimal('5'),
             displayed_on_eshop=False
         )
 
@@ -270,9 +276,10 @@ class BaseTestCase(NereidTestCase):
         account_create_chart = POOL.get(
             'account.create_chart', type="wizard")
 
-        account_template, = AccountTemplate.search(
-            [('parent', '=', None)]
-        )
+        account_template, = AccountTemplate.search([
+            ('parent', '=', None),
+            ('name', '=', 'Minimal Account Chart'),
+        ])
 
         session_id, _, _ = account_create_chart.create()
         create_chart = account_create_chart(session_id)
@@ -377,7 +384,9 @@ class BaseTestCase(NereidTestCase):
                 'company': self.company.id,
             }
         )
-        CONTEXT.update(self.User.get_preferences(context_only=True))
+        Transaction().context.update(
+            self.User.get_preferences(context_only=True)
+        )
 
         # Create Fiscal Year
         self._create_fiscal_year(company=self.company.id)
